[![Python 3.8](https://img.shields.io/badge/python-3.8-blue.svg)](https://www.python.org/downloads/release/python-382/) [![PyPI version](https://badge.fury.io/py/pymakeplots.svg)](https://badge.fury.io/py/pymakeplots) 

A python module for making publication quality plots and output datafiles (including moment zero, one, two, PVD's and spectra) from interferometric datacubes. 


### Install

You can install pymakeplots with `pip install pymakeplots`. Alternatively you can download the code, navigate to the directory you unpack it too, and run `python setup.py install`.
    
It requires the following modules (which pip should install for you if required):

* numpy
* matplotlib
* scipy
* astropy
* pafit


### Documentation

Check the quick start/tutorial jupyter notebook [here](https://github.com/TimothyADavis/pymakeplots/blob/master/pymakeplots/quickstart/pymakeplots_tutorial.ipynb)


### Commumication

If you find any bugs, or wish to be kept up to date when new versions of this software are released, please raise an issue here on github, or email us at DavisT -at- cardiff.ac.uk.

### License

pymakeplots is MIT-style licensed, as found in the LICENSE file.


Many thanks,

Dr Timothy A. Davis

Cardiff, UK
